@@ -4,13 +4,16 @@
 #include <QWidget>
 #include <QPixmap>
 
-#include "utils.h"
-
 
 
+#include "types.h"
 
 class QPaintEvent;
 class QResizeEvent;
+namespace QtMobility {
+    class QSystemDisplayInfo;
+}
+
 
 
 class LuxWidget : public QWidget
@@ -28,11 +31,11 @@ protected:
 private:
     QPixmap       cache;
     bool          dirty;
+    QtMobility::QSystemDisplayInfo *displayinfo;
 
     int timerId;
     LuxusUnits currentUnit;
 
-
 };
 
 #endif
